==> haskell-skylighting-format-latex-0.1-208-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-JKsl4ZBMb67KWREpXcJ0RZ
key:                  skylighting-format-latex-0.1-JKsl4ZBMb67KWREpXcJ0RZ
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  ad5147dcec9568a69869578ccdbb6dc6
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-JKsl4ZBMb67KWREpXcJ0RZ
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.1.1-KkIxhYeU7wzIE2N1xgJDsk text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-latex-0.1-213-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-10fJOGs2h9KukaQUniwtp
key:                  skylighting-format-latex-0.1-10fJOGs2h9KukaQUniwtp
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  2d6bc6d4ce173e743d5fac1e37401dfa
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-10fJOGs2h9KukaQUniwtp
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.1.1-Ji5KRC8VspE5K0hLPCbADW text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
